==> 1.0.0.tar.gz: lib/src/packets-schedule.dart <==
import 'packets-general.dart'
    show PREFIX, START_FILE_NAME_HEX, zeros, POSTFIX, Packet;

const START_SCHEDULE_PREFIX = '0101000a';
const START_SCHEDULE_CALL = '000030';
const START_SCHEDULE_POSTFIX = '4f'; // This value depends on the filename?
const END_SCHEDULE_PREFIX = '040a0000';
const END_SCHEDULE_POSTFIX = '0d';
const LIGHT_SCHEDULE_PREFIX = '01020008';

Packet createScheduleStartPacket(String channelBytes) {
  final data = PREFIX +
      START_SCHEDULE_PREFIX +
      zeros(2) +
      START_FILE_NAME_HEX +
      START_SCHEDULE_CALL +
      zeros(84 - (START_FILE_NAME_HEX.length + START_SCHEDULE_CALL.length)) +
      channelBytes +
      START_SCHEDULE_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

Packet createScheduleDataPacket(
    String channelBytes, int hour, bool halfhour, List<int> value) {
  const hourBase = 10;
  const halfhourBase = 41;
  final step = 3 * hour;
  final postfix = ((halfhour ? halfhourBase : hourBase) +
          value[0] +
          value[1] +
          value[2] +
          value[3] +
          value[4] +
          step)
      .toRadixString(16)
      .padLeft(2, '0');
  final cutoffPostfix = postfix.length > 2 ? postfix.substring(1, 3) : postfix;
  final data = PREFIX +
      LIGHT_SCHEDULE_PREFIX +
      (hour * 2 + (halfhour ? 1 : 0)).toRadixString(16).padLeft(2, '0') +
      hour.toRadixString(16).padLeft(2, '0') +
      (halfhour ? '1e' : '00') +
      value[0].toRadixString(16).padLeft(2, '0') +
      value[1].toRadixString(16).padLeft(2, '0') +
      value[2].toRadixString(16).padLeft(2, '0') +
      value[3].toRadixString(16).padLeft(2, '0') +
      value[4].toRadixString(16).padLeft(2, '0') +
      zeros(70) +
      channelBytes +
      cutoffPostfix +
      POSTFIX;
  return Packet(data, true);
}

Packet createScheduleEndPacket(String channelBytes) {
  final data = PREFIX +
      END_SCHEDULE_PREFIX +
      zeros(86) +
      channelBytes +
      END_SCHEDULE_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

List<Packet> createSchedulePackets(String channelBytes, List<List<int>> schedule) {
  final List<Packet> res = [];
  res.add(createScheduleStartPacket(channelBytes));
  for (var i = 0; i < schedule.length; i++) {
    final hour = (i / 2).floor();
    final halfhour = i % 2 == 1;
    final List<int> value = [];
    for (var j = 0; j < 5; j++) {
      value.add(schedule[i][j]);
    }
    res.add(createScheduleDataPacket(channelBytes, hour, halfhour, value));
  }
  res.add(createScheduleEndPacket(channelBytes));
  return res;
}

==> 1.0.3.tar.gz: lib/src/packets-schedule.dart <==
import 'packets-general.dart'
    show PREFIX, START_FILE_NAME_HEX, zeros, POSTFIX, Packet;

const START_SCHEDULE_PREFIX = '0101000a';
const START_SCHEDULE_CALL = '000030';
const START_SCHEDULE_POSTFIX = '4f'; // This value depends on the filename?
const END_SCHEDULE_PREFIX = '040a0000';
const END_SCHEDULE_POSTFIX = '0d';
const LIGHT_SCHEDULE_PREFIX = '01020008';

Packet createScheduleStartPacket(String controllerId) {
  final data = PREFIX +
      START_SCHEDULE_PREFIX +
      zeros(2) +
      START_FILE_NAME_HEX +
      START_SCHEDULE_CALL +
      zeros(84 - (START_FILE_NAME_HEX.length + START_SCHEDULE_CALL.length)) +
      controllerId +
      START_SCHEDULE_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

Packet createScheduleDataPacket(
    String controllerId, int hour, bool halfhour, List<int> value) {
  const hourBase = 10;
  const halfhourBase = 41;
  final step = 3 * hour;
  final postfix = ((halfhour ? halfhourBase : hourBase) +
          value[0] +
          value[1] +
          value[2] +
          value[3] +
          value[4] +
          step)
      .toRadixString(16)
      .padLeft(2, '0');
  final cutoffPostfix = postfix.length > 2 ? postfix.substring(1, 3) : postfix;
  final data = PREFIX +
      LIGHT_SCHEDULE_PREFIX +
      (hour * 2 + (halfhour ? 1 : 0)).toRadixString(16).padLeft(2, '0') +
      hour.toRadixString(16).padLeft(2, '0') +
      (halfhour ? '1e' : '00') +
      value[0].toRadixString(16).padLeft(2, '0') +
      value[1].toRadixString(16).padLeft(2, '0') +
      value[2].toRadixString(16).padLeft(2, '0') +
      value[3].toRadixString(16).padLeft(2, '0') +
      value[4].toRadixString(16).padLeft(2, '0') +
      zeros(70) +
      controllerId +
      cutoffPostfix +
      POSTFIX;
  return Packet(data, true);
}

Packet createScheduleEndPacket(String controllerId) {
  final data = PREFIX +
      END_SCHEDULE_PREFIX +
      zeros(86) +
      controllerId +
      END_SCHEDULE_POSTFIX +
      POSTFIX;
  return Packet(data, true);
}

List<Packet> createSchedulePackets(
    String controllerId, List<List<int>> schedule) {
  final res = <Packet>[];
  res.add(createScheduleStartPacket(controllerId));
  for (var i = 0; i < schedule.length; i++) {
    final hour = (i / 2).floor();
    final halfhour = i % 2 == 1;
    final value = <int>[];
    for (var j = 0; j < 5; j++) {
      value.add(schedule[i][j]);
    }
    res.add(createScheduleDataPacket(controllerId, hour, halfhour, value));
  }
  res.add(createScheduleEndPacket(controllerId));
  return res;
}
